=======
History
=======

0.3.1 (2022-04-13)
------------------

* Fixes to documentation

0.3.0 (2022-04-13)
------------------

* Added icons
* Added encoding
* Changed exe name
* UPX packing on Windows
* Documentation updates

0.2.4 (2022-04-06)
------------------

* More testing
* Bump2Version configuration fixes
* Fixing up tox.ini

0.2.3 (2022-04-01)
------------------

* Added tests

0.2.2 (2022-04-01)
------------------

* Fixed documentation
* Fixed exceptions

0.2.1 (2022-03-31)
------------------

* Bug fixes

0.2.0 (2022-03-30)
------------------

* Added GUI

0.1.1 (2022-03-23)
------------------

* Faster key detection
* Python typing
* Added documentation
* Keeping files compatible with RPGMaker MV/MZ
  * Using .png or .ogg instead of real extension

0.1.0 (2021-04-18)
------------------

* First release on PyPI.
